@@ -9,6 +9,9 @@ module Network.WebSockets
     , defaultAcceptRequest
     , acceptRequestWith
     , rejectRequest
+    , RejectRequest(..)
+    , defaultRejectRequest
+    , rejectRequestWith
 
       -- * Main connection type
     , Connection
@@ -17,16 +20,27 @@ module Network.WebSockets
     , ConnectionOptions (..)
     , defaultConnectionOptions
 
+      -- ** Compression options
+    , CompressionOptions (..)
+    , PermessageDeflate (..)
+    , defaultPermessageDeflate
+
+      -- ** Protection limits
+    , SizeLimit (..)
+
       -- * Sending and receiving messages
     , receive
     , receiveDataMessage
     , receiveData
     , send
     , sendDataMessage
+    , sendDataMessages
     , sendTextData
     , sendTextDatas
     , sendBinaryData
+    , sendBinaryDatas
     , sendClose
+    , sendCloseCode
     , sendPing
 
       -- * HTTP Types
