@@ -11,8 +11,9 @@ module Network.WebSockets.Client
 
 
 --------------------------------------------------------------------------------
-import qualified Blaze.ByteString.Builder      as Builder
+import qualified Data.ByteString.Builder       as Builder
 import           Control.Exception             (bracket, finally, throwIO)
+import           Control.Monad                 (void)
 import           Data.IORef                    (newIORef)
 import qualified Data.Text                     as T
 import qualified Data.Text.Encoding            as T
@@ -56,20 +57,20 @@ runClientWith :: String             -- ^ Host
 runClientWith host port path0 opts customHeaders app = do
     -- Create and connect socket
     let hints = S.defaultHints
-                    {S.addrFamily = S.AF_INET, S.addrSocketType = S.Stream}
+                    {S.addrSocketType = S.Stream}
 
         -- Correct host and path.
         fullHost = if port == 80 then host else (host ++ ":" ++ show port)
         path     = if null path0 then "/" else path0
-    addrInfos <- S.getAddrInfo (Just hints) (Just host) (Just $ show port)
-    sock      <- S.socket S.AF_INET S.Stream S.defaultProtocol
+    addr:_ <- S.getAddrInfo (Just hints) (Just host) (Just $ show port)
+    sock      <- S.socket (S.addrFamily addr) S.Stream S.defaultProtocol
     S.setSocketOption sock S.NoDelay 1
 
     -- Connect WebSocket and run client
     res <- finally
-        (S.connect sock (S.addrAddress $ head addrInfos) >>
+        (S.connect sock (S.addrAddress addr) >>
          runClientWithSocket sock fullHost path opts customHeaders app)
-        (S.sClose sock)
+        (S.close sock)
 
     -- Clean up
     return res
@@ -100,11 +101,12 @@ runClientWithStream stream host path opts customHeaders app = do
         Nothing       -> throwIO $ OtherHandshakeException $
             "Network.WebSockets.Client.runClientWithStream: no handshake " ++
             "response from server"
-    -- Note that we pattern match to evaluate the result here
-    Response _ _ <- return $ finishResponse protocol request response
-    parse        <- decodeMessages protocol stream
-    write        <- encodeMessages protocol ClientConnection stream
-    sentRef      <- newIORef False
+    void $ either throwIO return $ finishResponse protocol request response
+    parse   <- decodeMessages protocol
+                (connectionFramePayloadSizeLimit opts)
+                (connectionMessageDataSizeLimit opts) stream
+    write   <- encodeMessages protocol ClientConnection stream
+    sentRef <- newIORef False
 
     app Connection
         { connectionOptions   = opts
